@@ -1,7 +1,8 @@
 "shannon" <-
-function(vect){
+function(vect, proba=TRUE){
     if (!is.vector(vect)) stop("vector expected")
-    if (!all.equal(sum(vect),1)) stop("vector sum must be 1")
+    if (!proba) vect<-vect/sum(vect)
+    if (!all.equal(sum(vect),1)) stop("probability vector must sum to 1")
     vect<-vect*log(vect,2)
     h<-sum(vect[is.finite(vect)])
     hmax<-log(1/length(vect),2)
